@@ -20,7 +20,7 @@
 /*                                                                        */
 /**************************************************************************/
 
-/* $Id: ml_gdk.c 1428 2008-10-30 17:02:27Z ben_99_9 $ */
+/* $Id$ */
 
 #include <string.h>
 #include <gdk/gdk.h>
@@ -86,6 +86,19 @@ CAMLprim value ml_test_##conv (value mask, value test) \
 Make_test(GdkModifier_val)
 Make_test(GdkWindowState_val)
 
+/* Platform */
+
+value ml_gdk_get_platform()
+{
+#ifdef GDK_WINDOWING_WIN32
+  return MLTAG_WIN32;
+#elif defined(GDK_WINDOWING_QUARTZ)
+  return MLTAG_QUARTZ;
+#else
+  return MLTAG_X11;
+#endif
+}
+
 /* Colormap */
 
 ML_0 (gdk_colormap_get_system, Val_GdkColormap)
@@ -253,6 +266,8 @@ CAMLprim value ml_gdk_drawable_get_size (value drawable)
 ML_3 (gdk_window_set_back_pixmap, GdkWindow_val, GdkPixmap_val, Int_val, Unit)
 ML_2 (gdk_window_set_cursor, GdkWindow_val, GdkCursor_val, Unit)
 ML_1 (gdk_window_clear, GdkWindow_val, Unit)
+ML_5 (gdk_window_clear_area, GdkWindow_val, Int_val, Int_val, Int_val, Int_val,
+      Unit)
 ML_0 (GDK_ROOT_PARENT, Val_GdkWindow)
 ML_1 (gdk_window_get_parent, GdkWindow_val, Val_GdkWindow)
 
